open Gobject
open Data
module Object = GtkObject

  open GtkSourceView_types

let may_cons = Property.may_cons
let may_cons_opt = Property.may_cons_opt

module SourceStyleScheme = struct
  let cast w : source_style_scheme obj = try_cast w "GtkSourceStyleScheme"
  let create pl : source_style_scheme obj =
    Gobject.unsafe_create "GtkSourceStyleScheme" pl
end

module SourceLanguage = struct
  let cast w : source_language obj = try_cast w "GtkSourceLanguage"
  module S = struct
    open GtkSignal
    let tag_style_changed =
      {name="tag_style_changed"; classe=`sourcelanguage; marshaller=fun f ->
       marshal1 string "GtkSourceLanguage::tag_style_changed" f}
  end
  let create pl : source_language obj =
    Gobject.unsafe_create "GtkSourceLanguage" pl
end

module SourceLanguagesManager = struct
  let cast w : source_languages_manager obj =
    try_cast w "GtkSourceLanguagesManager"
  let create pl : source_languages_manager obj =
    Gobject.unsafe_create "GtkSourceLanguagesManager" pl
end

module SourceTagStyle = struct
  let cast w : source_tag_style obj = try_cast w "GtkSourceTagStyle"
  module P = struct
    let foreground : ([>`sourcetagstyle],_) property =
      {name="foreground"; conv=(unsafe_pointer : Gdk.color data_conv)}
    let background : ([>`sourcetagstyle],_) property =
      {name="background"; conv=(unsafe_pointer : Gdk.color data_conv)}
    let italic : ([>`sourcetagstyle],_) property =
      {name="italic"; conv=boolean}
    let bold : ([>`sourcetagstyle],_) property = {name="bold"; conv=boolean}
    let underline : ([>`sourcetagstyle],_) property =
      {name="underline"; conv=boolean}
    let strikethrough : ([>`sourcetagstyle],_) property =
      {name="strikethrough"; conv=boolean}
  end
  let create pl : source_tag_style obj =
    Gobject.unsafe_create "GtkSourceTagStyle" pl
  let make_params ~cont pl ?foreground ?background ?italic ?bold ?underline
      ?strikethrough =
    let pl = (
      may_cons P.foreground foreground (
      may_cons P.background background (
      may_cons P.italic italic (
      may_cons P.bold bold (
      may_cons P.underline underline (
      may_cons P.strikethrough strikethrough pl)))))) in
    cont pl
end

module SourceTag = struct
  let cast w : source_tag obj = try_cast w "GtkSourceTag"
  module P = struct
    let id : ([>`sourcetag],_) property = {name="id"; conv=string}
  end
  let create ?id pl : source_tag obj =
    let pl = (may_cons P.id id pl) in
    Gobject.unsafe_create "GtkSourceTag" pl
end

module SourceTagTable = struct
  let cast w : source_tag_table obj = try_cast w "GtkSourceTagTable"
  module S = struct
    open GtkSignal
    let changed =
      {name="changed"; classe=`sourcetagtable; marshaller=marshal_unit}
  end
  let create pl : source_tag_table obj =
    Gobject.unsafe_create "GtkSourceTagTable" pl
end

module SourceMarker = struct
  let cast w : source_marker obj = try_cast w "GtkSourceMarker"
  let create pl : source_marker obj =
    Gobject.unsafe_create "GtkSourceMarker" pl
end

module SourceBuffer = struct
  let cast w : source_buffer obj = try_cast w "GtkSourceBuffer"
  module P = struct
    let check_brackets : ([>`sourcebuffer],_) property =
      {name="check-brackets"; conv=boolean}
    let escape_char : ([>`sourcebuffer],_) property =
      {name="escape-char"; conv=uint}
    let highlight : ([>`sourcebuffer],_) property =
      {name="highlight"; conv=boolean}
    let language : ([>`sourcebuffer],_) property =
      {name="language"; conv=(gobject : source_language obj data_conv)}
    let max_undo_levels : ([>`sourcebuffer],_) property =
      {name="max-undo-levels"; conv=int}
    let tag_table : ([>`sourcebuffer],_) property =
      {name="tag-table"; conv=(gobject : source_tag_table obj data_conv)}
  end
  module S = struct
    open GtkSignal
    let can_redo =
      {name="can_redo"; classe=`sourcebuffer; marshaller=fun f ->
       marshal1 boolean "GtkSourceBuffer::can_redo" f}
    let can_undo =
      {name="can_undo"; classe=`sourcebuffer; marshaller=fun f ->
       marshal1 boolean "GtkSourceBuffer::can_undo" f}
    let highlight_updated =
      {name="highlight_updated"; classe=`sourcebuffer; marshaller=fun f ->
       marshal2 (unsafe_pointer : Gtk.text_iter data_conv)
         (unsafe_pointer : Gtk.text_iter data_conv)
         "GtkSourceBuffer::highlight_updated" f}
    let marker_updated =
      {name="marker_updated"; classe=`sourcebuffer; marshaller=fun f ->
       marshal1 (unsafe_pointer : Gtk.text_iter data_conv)
         "GtkSourceBuffer::marker_updated" f}
  end
  let create ?tag_table pl : source_buffer obj =
    let pl = (may_cons P.tag_table tag_table pl) in
    Gobject.unsafe_create "GtkSourceBuffer" pl
  let make_params ~cont pl ?check_brackets ?escape_char ?highlight ?language
      ?max_undo_levels =
    let pl = (
      may_cons P.check_brackets check_brackets (
      may_cons P.escape_char escape_char (
      may_cons P.highlight highlight (
      may_cons P.language language (
      may_cons P.max_undo_levels max_undo_levels pl))))) in
    cont pl
end

module SourceView = struct
  let cast w : source_view obj = try_cast w "GtkSourceView"
  module P = struct
    let auto_indent : ([>`sourceview],_) property =
      {name="auto-indent"; conv=boolean}
    let highlight_current_line : ([>`sourceview],_) property =
      {name="highlight-current-line"; conv=boolean}
    let insert_spaces_instead_of_tabs : ([>`sourceview],_) property =
      {name="insert-spaces-instead-of-tabs"; conv=boolean}
    let margin : ([>`sourceview],_) property = {name="margin"; conv=uint}
    let show_line_markers : ([>`sourceview],_) property =
      {name="show-line-markers"; conv=boolean}
    let show_line_numbers : ([>`sourceview],_) property =
      {name="show-line-numbers"; conv=boolean}
    let show_margin : ([>`sourceview],_) property =
      {name="show-margin"; conv=boolean}
    let smart_home_end : ([>`sourceview],_) property =
      {name="smart-home-end"; conv=boolean}
    let tabs_width : ([>`sourceview],_) property =
      {name="tabs-width"; conv=uint}
  end
  module S = struct
    open GtkSignal
    let redo = {name="redo"; classe=`sourceview; marshaller=marshal_unit}
    let undo = {name="undo"; classe=`sourceview; marshaller=marshal_unit}
  end
  let create pl : source_view obj = Object.make "GtkSourceView" pl
  let make_params ~cont pl ?auto_indent ?highlight_current_line
      ?insert_spaces_instead_of_tabs ?margin ?show_line_markers
      ?show_line_numbers ?show_margin ?smart_home_end ?tabs_width =
    let pl = (
      may_cons P.auto_indent auto_indent (
      may_cons P.highlight_current_line highlight_current_line (
      may_cons P.insert_spaces_instead_of_tabs insert_spaces_instead_of_tabs (
      may_cons P.margin margin (
      may_cons P.show_line_markers show_line_markers (
      may_cons P.show_line_numbers show_line_numbers (
      may_cons P.show_margin show_margin (
      may_cons P.smart_home_end smart_home_end (
      may_cons P.tabs_width tabs_width pl))))))))) in
    cont pl
end

